@@ -8,8 +8,8 @@ use thiserror::Error;
 
 #[derive(Error, Debug, Clone, PartialEq)]
 pub enum FormatErr {
-    #[error("attribute not found")]
-    AttributeNotFound,
+    #[error("attribute not found: {0}")]
+    AttributeNotFound(String),
     #[error("{} is missing{}",
         .item.clone().unwrap_or_else(|| "attribute".to_string()),
         match .axis_name {
@@ -34,7 +34,7 @@ pub enum FormatErr {
     SymmetricEncryption(String),
     #[error("symmetric decryption {0}")]
     SymmetricDecryption(String),
-    #[error("asymmetric encryption {0}")]
+    #[error("asymmetric decryption {0}")]
     AsymmetricDecryption(String),
     #[error("attribute capacity overflow")]
     CapacityOverflow,
